// Persistence of Vision Ray Tracer Scene Description File
// File: SMS box.pov
// Vers: 3.1
// Desc: Master System box
// Auth: Maxim
//
// This is a very simple representation of an SMS box, designed for making
// fake "box shots" for my website.
// You must save two image files into the same directory, called "front.png"
// and "side.png". I suggest you base your image on a real box scan, copying
// from blank areas to "delete" existing graphics where necessary; then copy
// the required ares into the files needed. Using a real image editor which 
// supports layers is highly recommended.

#version 3.1;

#include "colors.inc"
#include "textures.inc"

global_settings
{
  assumed_gamma 1.0
}

// ----------------------------------------
camera {
  location  <0.0, 0.5, -4.0>
  direction 1.5*z
  right     4/3*x
  look_at   <0.0, 0.0,  0.0>
}

sky_sphere {
  pigment {color White}
}
   
light_source {
  0*x // light's position (translated below)
  color White
  translate <30, 30, -30>
}
light_source {
  0*x // light's position (translated below)
  color White
  translate <-30, 30, -30>
}

#declare borderwidth=0.02;
#declare boxx=1;
#declare boxy=1.39;
#declare boxz=0.20;
#declare paperwidth=0.00001;

union {
  // Main box
  box {
    <0,0,0>
    <boxx,boxy,boxz>
    texture {
      pigment {color Black}
    }
  }
  
  // Front cover
  box {
    <0,0,0>
    <1,1,paperwidth>
    texture {
      pigment {
        image_map {
          png "front.png"
          map_type 0 // 0=planar, 1=spherical, 2=cylindrical, 5=torus
          interpolate 2 // 0=none, 1=linear, 2=bilinear, 4=normalized distance
        }
      }
    }
    scale <boxx-borderwidth,boxy-borderwidth*2,1>
    translate <0,borderwidth,-paperwidth>
  }

  // Front cover
  box {
    <0,0,0>
    <1,1,paperwidth>
    texture {
      pigment {
        image_map {
          png "side.png"
          map_type 0 // 0=planar, 1=spherical, 2=cylindrical, 5=torus
          interpolate 2 // 0=none, 1=linear, 2=bilinear, 4=normalized distance
        }
      }
    }
    rotate <0,90,0>
    scale <1,boxy-borderwidth*2,boxz>
    translate <-paperwidth,borderwidth,boxz>
  }

  // Base for shadow
  box {
    <-5,-1,-5>
    < 5,0, 5>
    texture {pigment{color White} finish{reflection 0 ambient 0.4} }
  }
  

  translate <-boxx/2,-boxy/2,-boxz/2>
  rotate <0,-30,0>
}
